@@ -39,6 +39,7 @@ import java.util.List;
 import javax.imageio.ImageIO;
 import javax.imageio.IIOException;
 import javax.imageio.ImageReader;
+import javax.imageio.ImageWriteParam;
 import javax.imageio.metadata.IIOMetadata;
 import javax.imageio.stream.ImageInputStream;
 
@@ -155,7 +156,9 @@ public class PDJpeg extends PDXObjectImage
      *
      * @param doc The document to create the image as part of.
      * @param bi The image to convert to a jpeg
-     * @param compressionQuality The quality level which is used to compress the image
+     * @param compressionQuality The desired JPEG compression quality; between 0
+     * (best compression) and 1 (best image quality). See
+     * {@link ImageWriteParam#setCompressionQuality(float)} for more details.
      * @throws IOException If there is an error processing the jpeg data.
      */
     public PDJpeg( PDDocument doc, BufferedImage bi, float compressionQuality ) throws IOException
@@ -369,7 +372,11 @@ public class PDJpeg extends PDXObjectImage
             {
                 throw new RuntimeException("No ImageReaders found");
             }
-            reader = (ImageReader) readers.next();
+            reader = readers.next();
+            if (reader == null)
+            {
+                throw new RuntimeException("ImageReader is null");
+            }
             reader.setInput(input);
             IIOMetadata meta = reader.getImageMetadata(0);
             if (meta != null)
@@ -433,7 +440,11 @@ public class PDJpeg extends PDXObjectImage
         }
         // read the raster information only
         // avoid to access the meta information
-        ImageReader reader = (ImageReader) readers.next();
+        ImageReader reader = readers.next();
+        if (reader == null)
+        {
+            throw new RuntimeException("ImageReader is null");
+        }
         reader.setInput(input);
         Raster raster = reader.readRaster(0, reader.getDefaultReadParam());
         input.close();
