@@ -333,7 +333,8 @@ public class Overlay
         }
         else
         {
-            throw new IOException("Contents are unknown type:" + contents.getClass().getName());
+            throw new IOException("Unknown content type: " + 
+                    (contents == null ? "(null)" : contents.getClass().getName()));
         }
         return contentStreams;
     }
@@ -362,7 +363,8 @@ public class Overlay
                 }
                 else
                 {
-                    throw new IOException("Unknown content type:" + contents.getClass().getName());
+                    throw new IOException("Unknown content type: " +
+                            (contents == null ? "(null)" : contents.getClass().getName()));
                 }
                 // restore state
                 contentArray.add(createStream("Q\n"));
@@ -383,7 +385,8 @@ public class Overlay
                 }
                 else
                 {
-                    throw new IOException("Unknown content type:" + contents.getClass().getName());
+                    throw new IOException("Unknown content type: " +
+                            (contents == null ? "(null)" : contents.getClass().getName()));
                 }
                 break;
             default:
