@@ -35,7 +35,6 @@ import org.apache.pdfbox.cos.COSInteger;
 import org.apache.pdfbox.cos.COSName;
 import org.apache.pdfbox.cos.COSNumber;
 import org.apache.pdfbox.cos.COSStream;
-import org.apache.pdfbox.cos.COSString;
 import org.apache.pdfbox.exceptions.COSVisitorException;
 import org.apache.pdfbox.io.RandomAccess;
 import org.apache.pdfbox.pdmodel.PDDocument;
@@ -72,8 +71,6 @@ public class PDFMergerUtility
      */
     private static final Log LOG = LogFactory.getLog(PDFMergerUtility.class);
 
-    private static final String STRUCTURETYPE_DOCUMENT = "Document";
-
     private final List<InputStream> sources;
     private final List<FileInputStream> fileInputStreams;
     private String destinationFileName;
@@ -444,6 +441,7 @@ public class PDFMergerUtility
         {
             PDStream newStream = new PDStream(destination, srcMetadata.getUnfilteredStream(), false);
             newStream.getStream().mergeInto(srcMetadata);
+            ((COSDictionary) newStream.getCOSObject()).removeItem(COSName.FILTER);
             destCatalog.getCOSDictionary().setItem(COSName.METADATA, newStream);
         }
 
@@ -564,7 +562,7 @@ public class PDFMergerUtility
             }
             kDictLevel0.setItem(COSName.K, newKArray);
             kDictLevel0.setItem(COSName.P, destStructTree);
-            kDictLevel0.setItem(COSName.S, new COSString(STRUCTURETYPE_DOCUMENT));
+            kDictLevel0.setItem(COSName.S, COSName.DOCUMENT);
             destStructTree.setK(kDictLevel0);
         }
     }
